﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Arction.WPF.LightningChartUltimate;
using Arction.WPF.LightningChartUltimate.Axes;
using Arction.WPF.LightningChartUltimate.Views;
using Arction.WPF.LightningChartUltimate.Views.ViewXY;
using Arction.WPF.LightningChartUltimate.SeriesXY; 

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        LightningChartUltimate _chart; 

        public MainWindow()
        {
            InitializeComponent();

            _chart = new LightningChartUltimate();

            _chart.BeginUpdate();
            _chart.Title.Text = "Double-click segment to remove it"; 

            ViewXY v = _chart.ViewXY;
            v.YAxes.Clear();
            v.AxisLayout.Segments.Clear();
            v.AxisLayout.YAxesLayout = YAxesLayout.Segmented;
            v.LegendBox.Visible = false; 


            for (int i = 0; i < 6; i++)
            {
                YAxisSegment seg = new YAxisSegment(v.AxisLayout);
                v.AxisLayout.Segments.Add(seg);


                Color c = DefaultColors.SeriesForBlackBackgroundWPF[i]; 

                AxisY yAxis = new AxisY(v);
                yAxis.SegmentIndex = v.AxisLayout.Segments.IndexOf(seg);
                yAxis.AxisColor = c; 
                v.YAxes.Add(yAxis);
                

                if (i % 2 == 0)
                {
                    PointLineSeries pls = new PointLineSeries(v, v.XAxes[0], yAxis);
                    pls.Points = new SeriesPoint[]{new SeriesPoint(0,10), new SeriesPoint(5,5), new SeriesPoint(10, 2.5), new SeriesPoint(20, 6)};
                    pls.LineStyle.Color = c; 
                    v.PointLineSeries.Add(pls); 
                }

                else 
                {
                    IntensityGridSeries igs = new IntensityGridSeries(v, v.XAxes[0], yAxis);
                    igs.Data = new IntensityPoint[2, 2];
                    igs.Data[0, 0].Value = 0;
                    igs.Data[0, 1].Value = 10;
                    igs.Data[1, 1].Value = 20;
                    igs.Data[1, 0].Value = 5;
                    igs.SetRangesXY(0, 10, 0, 10);
                    v.IntensityGridSeries.Add(igs);
                }
            }


            _chart.MouseDoubleClick += _chart_MouseDoubleClick;

            _chart.ViewXY.FitView(); 
            
            _chart.EndUpdate(); 

            gridMain.Children.Add(_chart); 
        }

        void _chart_MouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
          
            Point pMouse = e.GetPosition(_chart); 
            GraphSegmentInfo s = _chart.ViewXY.GetGraphSegmentInfo();
            int iSegToBeRemoved = -1; 
            for (int iSeg = 0; iSeg < s.SegmentCount; iSeg++)
            {
                if (pMouse.Y >= s.SegmentTops[iSeg] && pMouse.Y <= s.SegmentBottoms[iSeg])
                {
                    iSegToBeRemoved = iSeg; 
                }
            }

            if (iSegToBeRemoved >= 0)
            {
                //Remove the segment, axis and series 

                RemoveSegment(iSegToBeRemoved); 
            }
        }

        //Remove segment, Y axes belonging to it, and all the series belonging to these Y axes 
        void RemoveSegment(int segmentIndex)
        {
            _chart.BeginUpdate();

            //Store Segment references in Tags
            foreach (AxisY yAxis in _chart.ViewXY.YAxes)
            {
                //Store segent reference 
                yAxis.Tag = _chart.ViewXY.AxisLayout.Segments[yAxis.SegmentIndex]; 
            }

            //Store Y axes references in Tags
            foreach (SeriesBaseXY s in _chart.ViewXY.GetAll2DSeries())
            {
                //Store segent reference 
                s.Tag = _chart.ViewXY.YAxes[s.AssignYAxisIndex];
            }

            //Delete all Y axes that belong to the segment to be removed
            List<AxisY> listOfYAxesToBeRemoved = new List<AxisY>(); 

            foreach (AxisY yAxis in _chart.ViewXY.YAxes)
            {
                if(yAxis.SegmentIndex == segmentIndex)
                {
                 
                    foreach (SeriesBaseXY s in _chart.ViewXY.GetSeriesOfAxisY(yAxis))
                    {
                        if(s is PointLineSeries)
                            _chart.ViewXY.PointLineSeries.Remove((PointLineSeries) s); 
                        else if(s is IntensityGridSeries)
                            _chart.ViewXY.IntensityGridSeries.Remove((IntensityGridSeries) s); 
                        s.Tag = null; 
                    }

                    listOfYAxesToBeRemoved.Add(yAxis); 
                } 
                
            }

            //Remove the Y axes
            foreach(AxisY yAxis in listOfYAxesToBeRemoved)
            {
                yAxis.Tag = null; 
                _chart.ViewXY.YAxes.Remove(yAxis); 
            }

            _chart.ViewXY.AxisLayout.Segments.RemoveAt(segmentIndex);

            
            //Set segment indices
            foreach (AxisY yAxis in _chart.ViewXY.YAxes)
            {
                yAxis.SegmentIndex = _chart.ViewXY.AxisLayout.Segments.IndexOf((YAxisSegment) yAxis.Tag);  
                yAxis.Tag = null;
            }

            //Set Y axis indices 
            foreach (SeriesBaseXY s in _chart.ViewXY.GetAll2DSeries())
            {
                s.AssignYAxisIndex = _chart.ViewXY.YAxes.IndexOf((AxisY)s.Tag);
                s.Tag = null; 
            }

            _chart.EndUpdate(); 
        }
    }
}
